# wallabag-client

Wallabag-client is a command line client for the self hosted read-it-later app [wallabag](https://www.wallabag.org/). Unlike to other services, wallabag is free and open source.

Wallabag-client is refactored version of existed wallabag-cli tool.

--------------------------------------------------------------------------------

## Features

- List entries (filterable)
- Show the content of an entry
- Add new entries
- Delete entries
- Mark existing entries as read
- Mark existing entries as starred
- Change the title of existing entries
